<template>
  <a-modal
    :title="title"
    :width="1000"
    :visible="visible"
    :maskClosable="false"
    :confirmLoading="confirmLoading"
    :okButtonProps="{ props: {disabled: disableSubmit} }"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">
        <a-row style="width: 100%">
          <a-col :span="24 / 2  ">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="仓库编码"
            >
              <a-input
                placeholder="将由系统生成"
                v-decorator="['code', validatorRules.code]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24 / 2">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="仓库名称"
            >
              <a-input
                placeholder="请输入仓库名称"
                v-decorator="['name', validatorRules.name]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row style="width: 100%">
          <a-col :span="24 / 2  ">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="仓库类型"
            >
              <j-dict-select-tag
                allow-clear
                :disabled="disableSubmit"
                :placeholder="disableSubmit?'':'请选择仓库类型'"
                :triggerChange="true"
                dictCode="warehouse_type"
                v-decorator="['type', validatorRules.type]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24 / 2">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="是否废品库"
            >
              <j-dict-select-tag
                allow-clear
                :disabled="disableSubmit"
                :placeholder="disableSubmit?'':'请选择是否废品库'"
                :triggerChange="true"
                dictCode="whether_waste_warehouse"
                v-decorator="['whetherWasteWarehouse', validatorRules.whetherWasteWarehouse]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row style="width: 100%">
          <a-col :span="24 / 2">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="库区库位管理"
            >
              <j-dict-select-tag
                allow-clear
                :disabled="disableSubmit"
                :placeholder="disableSubmit?'':'请选库区库位管理'"
                :triggerChange="true"
                dictCode="location_manage"
                v-decorator="['locationManage', validatorRules.locationManage]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24 / 2">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="服务对象类型"
            >
              <j-dict-select-tag
                allow-clear
                :disabled="disableSubmit"
                :placeholder="disableSubmit?'':'请选择服务对象类型'"
                :triggerChange="true"
                dictCode="service_object"
                v-decorator="['serviceObject', validatorRules.serviceObject]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row style="width: 100%">
          <a-col :span="24 / 2  ">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="自动化"
            >
              <j-dict-select-tag
                allow-clear
                :disabled="disableSubmit"
                :placeholder="disableSubmit?'':'请选择是否自动化'"
                :triggerChange="true"
                dictCode="whether_automation_warehouse"
                v-decorator="['whetherAutomationWarehouse', validatorRules.whetherAutomationWarehouse]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="{ span: 3 }"
              :wrapperCol="{ span: 21 }"
              label="备注"
            >
              <a-textarea
                allow-clear
                :disabled="disableSubmit"
                :placeholder="disableSubmit?'':'请输入备注'"
                v-decorator="['remark', validatorRules.remark]"
              />
            </a-form-item>
          </a-col>
        </a-row>

      </a-form>
    </a-spin>

    <template slot="footer">
      <a-button
        :style="{marginRight: '8px'}"
        @click="handleCancel"
      >
        关闭
      </a-button>
      <!-- <a-button
        v-if="!this.model.id"
        :disabled="disableSubmit || confirmLoading"
        :loading="confirmLoading"
        @click="handleOkAndAdd"
        type="primary"
      >保存并继续新增</a-button> -->
      <a-button
        :disabled="disableSubmit || confirmLoading"
        :loading="confirmLoading"
        @click="handleOk"
        type="primary"
      >确定</a-button>
    </template>

  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { postAction, requestPut, getAction } from '@/api/manage'
import { duplicateCheck } from '@/api/api'
import moment from 'moment'
import JImageUpload from '@/components/jeecg/JImage2Upload'
import Vue from 'vue'

export default {
  name: 'WarehouseModal',
  components: {
    JImageUpload
  },
  data() {
    return {
      title: "操作",
      visible: false,
      codeDisable: true,
      disableSubmit: false,
      model: {},
      headers: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        code: {
          rules: [
            { required: true, message: '请输入仓库编号!' },
          ]
        },
        name: {
          rules: [
            { required: true, message: '请输入仓库名称!' },
          ]
        },
        type: {
          rules: [
            { required: true, message: '请选择仓库类型!' },
          ]
        },
        whetherWasteWarehouse: {
          rules: [
            { required: true, message: '请选择是否废品库!' },
          ]
        },
        locationManage: {
          rules: [
            { required: true, message: '请选择库位库区管理!' },
          ]
        },
        whetherAutomationWarehouse: {
          rules: [
            { required: true, message: '请选择是否自动化库!' },
          ]
        },
        serviceObject: {
          rules: [
            { required: true, message: '请选择服务对象!' },
          ]
        },
        remark: {
          rules: [
            { min: 0, max: 100, message: '长度不超过 100 个字符', trigger: 'blur' },
          ]
        }
      },
      url: {
        add: "/base/warehouse/addWarehouse",
        edit: "/base/warehouse/edit",
      },
      //新增、编辑、删除、批量删除操作改变数据后刷新关联的组件的监听属性
      alterFlag: "",
    }
  },
  created() {

  },
  methods: {
    moment,

    add() {
      this.edit({});
    },

    edit(record) {
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.visible = true;
      this.disableSubmit = false;
      this.fileList = [];
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model,
          'code',
          'name',
          'type',
          'whetherWasteWarehouse',
          'locationManage',
          'whetherAutomationWarehouse',
          'serviceObject',
          'remark'));
      });
      if (record.id) {
        this.codeDisable = true;
      } else {
        this.codeDisable = false;
      }
    },

    close() {
      this.$emit('close');
      this.visible = false;
    },

    handleOk() {
      const that = this;
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);

          let obj;
          if (!this.model.id) {
            obj = postAction(this.url.add, formData);
          } else {
            obj = requestPut(this.url.edit, formData, { id: this.model.id });
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
              that.alterFlag = new Date();
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },

    handleCancel() {
      this.close()
    },

  },
  watch: {
    // alterFlag() {
    //   this.$bus.$emit('queryTreeData');
    // },
  }
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>